@@ -79,7 +79,9 @@ class Page(MPTTModel):
     updated = models.DateTimeField(_('updated'), auto_now=True)
     parent = models.ForeignKey('self', null=True, blank=True, related_name='subpages', verbose_name=_('parent'))
     meta_description = models.CharField(max_length=255, blank=True)
+    meta_keywords = models.CharField(max_length=255, blank=True)
     title = models.CharField(_('title'), max_length=255)
+    doc_title = models.CharField(_('document title'), max_length=255, blank=True)
     url = FiberURLField(blank=True)
     redirect_page = models.ForeignKey('self', null=True, blank=True, related_name='redirected_pages', verbose_name=_('redirect page'), on_delete=models.SET_NULL)
     mark_current_regexes = models.TextField(_('mark current regexes'), blank=True)
